%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% --- Simulation script for Centrifugal Compressor model Psi
% - Testing wet gas behaviour on the pressure ratio model
%
% Modeling and Control of Wet Gas Compressors
% 28.02.2017
%
% REV 01 N.T.

clear all;
load('datafile0103.mat');

w = linspace(0.05,0.5,50); % mass flow vector
N = 120000;             % constant speed in rpm
omega = N*2*pi/60;
ostr = num2str(omega);

%%%%%% Process and GT2252 parameters
params.sig = 1 - 2/12; % 12 blades
params.T01=293.15;
beta1b = 21.4;
beta2b = 54.1;
i = beta1b*2*pi/360;
r = beta2b*2*pi/360;
params.beta1b = i; %inducer blade angle in deg
params.beta2b = r; %exducer blade angle in deg
params.r1=20.1e-3; % iducer radii from hub
params.r2=26e-3;   % exducer radii from hub
params.A1=0.00283; A1 = 0.00283; % impeller eye radii

params.kappa = 1.4; % ratio of specific heats

 
rhog = 1.205; %gas density (air)
rhol =998.21; %liquid density (water)
cpg=1004.6; cvg = 717.4; cpw = 4182; cvw = cpw; % Incompressible

l = 0.04; D = 3.75*10^-3; f= 0.0188; % friction factor coeff
kf = 4*f*l/(2*D*rhog^2*A1^2*(sin(i))^2);
%GVF =1; % 100\% gas

gvf = [1 0.9997 0.9995 0.9993 0.999 0.98];
%gvf = [1 0.99 0.98 0.95 0.94 0.93];
f = @(j) j*rhog/(j*rhog + (1-j)*rhol);
gmf = zeros(length(gvf),1);
for i = 1:length(gvf)
   gmf(i) = f(gvf(i)); % calculate corresponding gmf 
end

colorVec = hsv(length(gvf)); % create a color vector with sat.
KF = zeros(length(gvf),1);
ma = zeros(length(gvf),1); % max values of psi
ind = zeros(length(gvf),1); % corr. x values of max

psiplot=figure;
hold on
%i = 1;
for i=1:length(gvf)

rho = rhog*gvf(i)+(1-gvf(i))*rhol; % homogenous density
%cp = cpg;
cp = cpg*gvf(i)+(1-gvf(i))*cpw; % homogenous specific heat
%cv = cvg*gvf(i)+(1-gvf(i))*cvw; % not used
params.cp=cp;
params.rho1=rho;
% params.kappa = cp/cv; % implies that psic increases for decrease gvf
%  kf = Ch*l / 2*Dh*rho1^2*A1^2*sin(beta1b)^2 , 
%   -   Ch = 4*f, f - friction factor
%   -   Dh, hydraulic diameter = 4D/a, a - wetted perimeter, 
%   -   l,  mean channel length = 6cm
% f = 0.3164*Re^-.25 = 0.0188 for Re = 80 000 

KF(i) = kf*(1 + (1 - gmf(i))); % increasing the friction loss with decreased GVF
params.kf = KF(i); % kf ~ calculated!

%%%%%%%%%%%%%%%%%%%%%%
[psi,dhct,dhc,dhi,dhf,phi] = psiC(w,omega,params); % function call to psii
% psi - p02/p01, pressure rise
% dhct - total stagnation entahlpy change
% dhci - total entalpy increase
% dhi - inducer loss entalpy
% dhf  - friction loss entalpy
max(dhf)
yyaxis left
plot(w,psi,'-','Color',colorVec(i,:));
yyaxis right
plot(w,dhf,'k-'); %Color',colorVec(i,:));
[jj,ii] = max(psi); % find maximum value 
ma(i) = jj; ind(i) = w(ii);
end
hold off % finishing the plotting figure
Legend=cell(length(gmf),1);
  for j=1:length(gmf)
    Legend{j}=strcat('\Psi_c, gmf=',...
        num2str(round(gmf(j,1),2)));%num2str(gvf(1,j)));
  end
legend(Legend);
%figure(3);
%plot(w, psi, sp17(1:10,1),sp17(1:10,2),'--');
title (['Pressure ratio for \omega = ',num2str(round(omega)),...
    ' rad/s',' (', num2str(N),' rpm)']);
xlabel 'mass flow [kg/s]'
yyaxis right
ylabel('Specifc energy J/Kg.K');
yyaxis left
ylabel('\Psi_c [-]');
%legend('\Psi_c','\Psi_{gt2252}')
axis([0.99*min(w) inf 0.98 ma(1)*1.05]);
grid on
hold on
plot(ind,ma,'k--'); % plot ("surge line")
hold off

% figure(1)
% plot(w, dhct, w, dhc,'--');
% title 'Total stagnation enthalpy change and ideal (no losses)'
% xlabel 'mass flow [kg/s]'
% ylabel('Enthalpy [J/kg]')
% legend('\Delta{h}_{02s}','\Delta{h}_{02}')
% grid on
% 
% figure(2)
% %plot(w, dhi,'k-',w,dhf,'k--');
% plot(w, dhi,w,dhf,'--');
% title 'Inducer and friction losses'
% xlabel 'mass flow [kg/s]'
% ylabel ('Enthalpy [J/kg]')
% legend('\Delta{h}_i','\Delta{h}_f')
% grid on

% load('wgc_log_psi.mat');
% wgcgvf=figure;
% %plot(w, dhi,'k-',w,dhf,'k--');
% plot(w,psi_wgc1,w,psi_wgc0995,w,psi_wgc099,w,psi_wgc0985,w,psi_wgc098,...
%         w,psi_wgc097,w,psi_wgc095);
% title '\Psi_c for dry and "wet gas", GVF=0.95-1'
% xlabel 'Mass flow [kg/s]'
% ylabel ('PR [-]')
% legend('\Psi_{c,dry}','\Psi_{c,99.5}','\Psi_{c,99}','\Psi_{c,98.5}'...
%             ,'\Psi_{c,98}','\Psi_{c,97}','\Psi_{c,95}')
% grid on

